@@ -5,14 +5,18 @@ package Hash::Util::FieldHash::Compat;
 use strict;
 use warnings;
 
-use constant REAL_FIELDHASH => do { local $@; eval { require Hash::Util::FieldHash } };
+use constant REAL_FIELDHASH => do { local $@; local $SIG{__DIE__}; eval { require Hash::Util::FieldHash } };
 
-# if we have it, allow fully qualified calls to ::Compat
-use if  REAL_FIELDHASH() => "Hash::Util::FieldHash" => ":all";
+BEGIN {
+	if ( REAL_FIELDHASH ) {
+		require Hash::Util::FieldHash;
+		Hash::Util::FieldHash->import(":all");
+	} else {
+		require Hash::Util::FieldHash::Compat::Heavy;
+	}
+}
 
-use if !REAL_FIELDHASH() => 'Hash::Util::FieldHash::Compat::Heavy';
-
-our $VERSION = "0.02";
+our $VERSION = "0.04";
 
 sub import {
 	if ( REAL_FIELDHASH ) {
